"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DateTimeTabs = exports.DateTimePicker = void 0;

var _react = require("react");

var _styledComponents = _interopRequireDefault(require("styled-components"));

var _practicalReactComponentsIcons = require("practical-react-components-icons");

var _designparams = require("../designparams");

var _DateTimeInformation = require("./DateTimeInformation");

var _TimePicker = require("./TimePicker");

var _DatePicker = require("./DatePicker");

var _Typography = require("../Typography");

var _Modal = require("../Modal");

var _Button = require("../Button");

var _ToggleButtonGroup = require("../ToggleButtonGroup");

var _Paper = require("../Paper");

var _Icon = require("../Icon");

var _jsxRuntime = require("react/jsx-runtime");

var _excluded = ["open", "date", "lang", "header", "onCancelAction", "onSaveAction", "hour12", "initialTab", "hour12MeridiemLabels"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var DateTimeTabs;
exports.DateTimeTabs = DateTimeTabs;

(function (DateTimeTabs) {
  DateTimeTabs["TwentyFour"] = "24";
  DateTimeTabs["AMPM"] = "AM/PM";
  DateTimeTabs["Min"] = "Min";
  DateTimeTabs["Date"] = "Date";
})(DateTimeTabs || (exports.DateTimeTabs = DateTimeTabs = {}));

var TitleContainer = _styledComponents.default.div.withConfig({
  displayName: "DateTimePicker__TitleContainer",
  componentId: "sc-ypqtka-0"
})(["color:", ";fill:", ";"], _ref => {
  var {
    theme
  } = _ref;
  return theme.color.text04();
}, _ref2 => {
  var {
    theme
  } = _ref2;
  return theme.color.text04();
});

var InformationContainer = _styledComponents.default.div.withConfig({
  displayName: "DateTimePicker__InformationContainer",
  componentId: "sc-ypqtka-1"
})(["padding:", " ", ";border-bottom:1px solid ", ";"], _designparams.spacing.large, _designparams.spacing.extraLarge, _ref3 => {
  var {
    theme
  } = _ref3;
  return theme.color.background01();
});

var ContentContainer = _styledComponents.default.div.withConfig({
  displayName: "DateTimePicker__ContentContainer",
  componentId: "sc-ypqtka-2"
})(["display:flex;flex-direction:column;justify-content:flex-start;height:100%;padding:", " ", ";"], _designparams.spacing.large, _designparams.spacing.extraLarge);

var FooterContainer = _styledComponents.default.div.withConfig({
  displayName: "DateTimePicker__FooterContainer",
  componentId: "sc-ypqtka-3"
})(["padding:0 ", " ", ";display:flex;flex-direction:row-reverse;> :last-child{margin-right:", ";}"], _designparams.spacing.large, _designparams.spacing.extraLarge, _designparams.spacing.medium);

var StyledPaper = (0, _styledComponents.default)(_Paper.Paper).withConfig({
  displayName: "DateTimePicker__StyledPaper",
  componentId: "sc-ypqtka-4"
})(["width:360px;height:688px;display:flex;flex-direction:column;justify-content:space-between;"]);

/**
 * DateTimePicker
 *
 * Dialog that can be used for date, time and time zone settings.
 */
var DateTimePicker = _ref4 => {
  var {
    open,
    date,
    lang = 'en',
    header,
    onCancelAction,
    onSaveAction,
    hour12,
    initialTab,
    hour12MeridiemLabels = {
      am: 'AM',
      pm: 'PM'
    }
  } = _ref4,
      modalProps = _objectWithoutProperties(_ref4, _excluded);

  var [dateTime, setDateTime] = (0, _react.useState)(new Date(date));
  (0, _react.useEffect)(() => setDateTime(new Date(date)), [date]);
  var [selectedTab, setSelectedTab] = (0, _react.useState)(() => {
    if (initialTab !== undefined && initialTab in DateTimeTabs) {
      return initialTab;
    }

    return hour12 ? DateTimeTabs.AMPM : DateTimeTabs.TwentyFour;
  });
  var onSaveClick = (0, _react.useCallback)(() => onSaveAction.onClick(dateTime.toISOString()), [dateTime, onSaveAction]);
  var onCancelClick = (0, _react.useCallback)(() => {
    onCancelAction.onClick();
    setDateTime(new Date(date));
  }, [date, onCancelAction]);
  var toggleButtonOptions = (0, _react.useMemo)(() => [{
    id: hour12 ? DateTimeTabs.AMPM : DateTimeTabs.TwentyFour,
    content: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.Icon, {
      icon: _practicalReactComponentsIcons.ClockHourIcon
    })
  }, {
    id: DateTimeTabs.Min,
    content: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.Icon, {
      icon: _practicalReactComponentsIcons.ClockMinuteIcon
    })
  }, {
    id: DateTimeTabs.Date,
    content: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.Icon, {
      icon: _practicalReactComponentsIcons.SystemDatetimeIcon
    })
  }], [hour12]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Modal.Modal, _objectSpread(_objectSpread({
    open: open,
    onClose: onCancelClick,
    verticallyCenter: true
  }, modalProps), {}, {
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(StyledPaper, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(InformationContainer, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(TitleContainer, {
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Typography.Typography, {
            variant: "dialog-heading",
            children: header
          })
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(InformationContainer, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_DateTimeInformation.DateTimeInformation, {
          dateTime: dateTime,
          lang: lang,
          hour12: hour12
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(ContentContainer, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_ToggleButtonGroup.ToggleButtonGroup, {
          onChange: setSelectedTab,
          options: toggleButtonOptions,
          values: [selectedTab]
        }), selectedTab === DateTimeTabs.TwentyFour ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_TimePicker.TimePickerTwentyFour, {
          onChange: setDateTime,
          date: dateTime
        }) : null, selectedTab === DateTimeTabs.Min ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_TimePicker.MinutePicker, {
          onChange: setDateTime,
          date: dateTime
        }) : null, selectedTab === DateTimeTabs.AMPM ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_TimePicker.TimePickerAMPM, {
          onChange: setDateTime,
          date: dateTime,
          hour12MeridiemLabels: hour12MeridiemLabels
        }) : null, selectedTab === DateTimeTabs.Date ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.DatePicker, {
          lang: lang,
          onChange: setDateTime,
          date: dateTime
        }) : null]
      }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(FooterContainer, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.Button, {
          onClick: onSaveClick,
          label: onSaveAction.label,
          variant: "primary"
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.Button, {
          onClick: onCancelClick,
          label: onCancelAction.label,
          variant: "secondary"
        })]
      })]
    })
  }));
};

exports.DateTimePicker = DateTimePicker;