/// <reference types="react" />
import { FieldProps } from '../utils/withField';
import { BaseSelectProps } from './BaseSelect';
import { Option } from './Select';
export interface MultiSelectProps<V extends string = string> extends Omit<BaseSelectProps<V>, 'value' | 'component' | 'options' | 'onChange' | 'selectMarker'> {
    /**
     * Selects items in the dropdown menu.
     * Must pre-exist in the dropdown menu and written in lowercase.
     * Otherwise no value is selected.
     */
    readonly value: ReadonlyArray<V>;
    /**
     * Used to create an array of selectable options.
     */
    readonly options: ReadonlyArray<Option<V>>;
    /**
     * Executes a JavaScript when a user changes the selected option of an element.
     */
    readonly onChange?: (value: ReadonlyArray<V>) => void;
    /**
     * Placeholder text when no value has been selected.
     */
    readonly placeholder?: string;
}
export declare function MultiSelect<V extends string = string>({ value, options, onChange, placeholder, ...props }: MultiSelectProps<V>): JSX.Element;
export declare const MultiSelectField: <V extends string = string>(props: FieldProps & MultiSelectProps<V>) => import("react").ReactElement<any, any> | null;
