import { TableHTMLAttributes, FC, ReactNode } from 'react';
declare type BaseElement = HTMLTableElement;
declare type BaseProps = TableHTMLAttributes<BaseElement>;
declare type BaseRowElement = HTMLTableRowElement;
declare type BaseRowProps = TableHTMLAttributes<BaseRowElement>;
export interface SimpleTableRowProps extends BaseRowProps {
    readonly children: ReadonlyArray<ReactNode>;
    /**
     * `class` to be passed to the component.
     */
    readonly className?: BaseProps['className'];
    /**
     * Optional flag to disable entire row.
     */
    readonly disabled?: boolean;
    /**
     * Function callback on row clicked
     */
    readonly onClick?: BaseRowProps['onClick'];
}
export declare const SimpleTableRow: FC<SimpleTableRowProps>;
export interface SimpleTableProps extends BaseProps {
    readonly children?: ReactNode;
    /**
     * `class` to be passed to the component.
     */
    readonly className?: BaseProps['className'];
    /**
     * The maximum height of the table in number of rows,
     * more rows will cause a scrollbar to appear.
     */
    readonly maxHeight: number;
    /**
     * Override theme's default setting for `compact` if set.
     */
    readonly compact?: boolean;
    /**
     * React element that will go into the top of the table.
     */
    readonly header: ReactNode;
    /**
     * Override default column width by specified width (%) if set.
     */
    readonly widths?: ReadonlyArray<number>;
}
export declare const SimpleTable: FC<SimpleTableProps>;
export {};
